// P2PickupCustom
// MultiPickup that allows setting custom static meshes and skins for client replication.
class P2PickupCustom extends MultiPickup
	hidecategories(MultiPickup);

var() array< class<Pickup> > PickupClasses; // same as MultiPickup
var() enum ECustomPickupType
{
	PT_Single, // one pickup only
	PT_Randomize, // randomize through PickupClasses
	PT_Cycle // cycle sequentially through PickupClasses
} PickupType;
var() StaticMesh PickupMesh; // Custom static mesh -- same for all pickups
var() array<Material> PickupSkins; // Skins for static mesh. Ignored if PickupMesh == None

var array<Pickup> PickupList;
var SyncInfo MySync; // SyncInfo for this pickup

// PostBeginPlay
// Spawn our SyncInfo for replicating the mesh/skins
event PostBeginPlay()
{
	local int i;

	Super(P2PowerupPickup).PostBeginPlay();

	//log(self$" class size "$PickupClasses.Length);
	// Make room for the new pickups
	PickupList.Insert(0, PickupClasses.Length);

	// Fill in the array
	for(i=0; i<PickupClasses.Length; i++)
	{
		PickupList[i] = spawn(PickupClasses[i], Owner,,Location);
		PickupList[i].SetCollision(false, false, false);
		ResetPickup(i);
	}

	// Pick your starting pickup (defaults to 0)
	if (PickupType == PT_Randomize)
		CurrIndex = Rand(PickupList.Length);

	if (PickupMesh != None || PickupSkins.Length > 0)
	{
		MySync = spawn(class'SyncInfo', Self,, Location);
		if (PickupMesh != None)
			SetStaticMesh(PickupMesh);
		for (i=0; i<PickupSkins.Length; i++)
			Skins[i] = PickupSkins[i];
	}
	else
	{
		bHidden=True;
	}
}

function SwapClass(class<Pickup> removethis, class<Pickup> replacer)
{
	local int i;
	// replace the class
	for(i=0; i<PickupClasses.Length; i++)
	{
		if(removethis == PickupClasses[i])
		{
			PickupClasses[i] = replacer;
		}
	}
}

///////////////////////////////////////////////////////////////////////////////
///////////////////////////////////////////////////////////////////////////////
function ResetPickup(int checkint)
{
	PickupList[checkint].GotoState('');
	PickupList[checkint].bHidden=true;
}

// PrepPickup
// Same as super, but keep the pickup hidden (use our static mesh instead)
function PrepPickup(int checkint)
{
	PickupList[checkint].GotoState('Pickup');
	if (PickupMesh == None)
	{
		PickupList[checkint].bHidden = False;
		//SetDrawType(DT_StaticMesh);
		//SetStaticMesh(PickupList[checkint].StaticMesh);
	}
}

// CyclePickup
// Same as super but use PickupType setting instead of obsoleted bRandomize
function CyclePickup()
{
	ResetPickup(CurrIndex);
	if (PickupType == PT_Single)
		return;

	if (PickupType == PT_Randomize)
		CurrIndex = Rand(PickupList.Length);
	else
	{
		CurrIndex++;
		if(CurrIndex >= PickupList.Length)
			CurrIndex=0;
	}
}

// state Pickup
// override bHidden
auto state Pickup
{
	///////////////////////////////////////////////////////////////////////////////
	// When touched by an actor.
	// Allow pawns to pick this up any time--even in the air just after dropping
	// it, but don't allow the one that dropped it, to grab it before it hits the
	// ground.
	///////////////////////////////////////////////////////////////////////////////
	function Touch( actor Other )
	{
		PickupList[CurrIndex].Touch(Other);

		if(PickupList[CurrIndex].GetStateName() != 'Pickup')
		{
			CyclePickup();
			// Send me to my sleeping state
			SetRespawn();
		}
	}

	///////////////////////////////////////////////////////////////////////////////
	///////////////////////////////////////////////////////////////////////////////
	function BeginState()
	{
		Super(P2PowerupPickup).BeginState();

		PrepPickup(CurrIndex);
		//bHidden=false;
	}
}

defaultproperties
{
}
