// BoomBoxInv
// Inventory item held by the player on maps using the RadioStation actor.
class BoomBoxInv extends P2PowerupInv;

// Import BoomBox icon
#exec TEXTURE IMPORT File=Textures\Radio.bmp Name=BoomBoxIcon Masked=True

// Internal variables
var RadioStation MyRadio;

var bool bSwitchChannel;
var int DesiredChannel;

// Localized strings
var localized string RadioIsOff;
var localized string NowListeningToChannel;
var localized string ErrorMessage;

// Replication block.
replication
{
	// Stuff the client needs to send to the server.
	reliable if (Role < ROLE_Authority)
		ServerSetAmount;

	// Stuff the server must send to the client.
	reliable if (Role == ROLE_Authority)
		ClientActivate;
}

// Amount is controlled on the server, but the client needs to set it so the player knows what channel the radio's on
function ServerSetAmount(int NewAmount)
{
	SetAmount(NewAmount);
}

simulated function ClientMessage(string Alert)
{
	if (PlayerController(Pawn(Owner).Controller) != None)
		PlayerController(Pawn(Owner).Controller).ClientMessage(Alert);
}

// init our MyRadio variable and get the current station
simulated event PostNetBeginPlay()
{
	//log("=== PostBeginPlay ===");
	//log("Super.PostNetBeginPlay();");
	Super.PostNetBeginPlay();
	// find the map's RadioStation
	foreach DynamicActors(class'RadioStation', MyRadio)
		break;

	if (MyRadio != None) // update our "amount" to display the radio station
	{
		//log("MyRadio found:" @ MyRadio);
		DesiredChannel = MyRadio.CurrentStation;
		ServerSetAmount(MyRadio.CurrentStation + 2);
		if (Role < ROLE_Authority)
		{
			MyRadio.LocalBoomBox = Self;
			//ClientMessage("My radio's local boom box is" @ MyRadio.LocalBoomBox);
		}
	}
	else // sanity check, should never happen
		ClientMessage(ErrorMessage);
}

simulated function Activate()
{
	ClientActivate();
}

simulated function ClientActivate()
{
	//log("=== Activate ===");
	if (MyRadio != None)
	{
		// Turn it off if we're at the max station
		// Can't use (CurrentStation + 1) % MAX_STATIONS because it would loop with no way of disabling the music
		bSwitchChannel = True;
		if (MyRadio.CurrentStation == MyRadio.MAX_STATIONS)
			DesiredChannel = -1;
		else // switch to the next station
			DesiredChannel = MyRadio.CurrentStation + 1;
		//log("The new DesiredChannel is" @ DesiredChannel);
	}
	else // sanity check, should never happen
		ClientMessage(ErrorMessage);
}

simulated event Tick(float Delta)
{
	Super.Tick(Delta);

	if (bSwitchChannel && MyRadio.PendingStation == DesiredChannel)
	{
		//log("=== Tick: bSwitchChannel && MyRadio.PendingStation == DesiredChannel");
		bSwitchChannel = False;

		// Tell the player what they're listening to
		ServerSetAmount(MyRadio.CurrentStation + 2);
		if (MyRadio.CurrentStation == -1)
			ClientMessage(RadioIsOff);
		else
			ClientMessage(NowListeningToChannel @ MyRadio.CurrentStation + 2);
	}
}

defaultproperties
{
	// Actor properties.
	bDisplayAmount=true
	MaxAmount=9
	bCanThrow=False
	PickupClass=None
	Icon=Texture'BoomBoxIcon'
	bSwitchChannel=false
	DesiredChannel=-1

    // Localized strings.
	RadioIsOff="Radio is off."
	NowListeningToChannel="Now listening to channel"
	ErrorMessage="The BoomBox is broken!"
	ItemName="Boom Box"
}
