// RadioStation
// A RadioStation is a special actor that plays music.
// Players get a "Boom Box" which can control the music on their machine.

// Has to extend from Mutator in order to grant the Boom Box Inv
class RadioStation extends Mutator
	placeable;

// allow 8 different radio stations (0..7)
// each radio station in RadioStation corresponds to Channel (Station# + 2) on the BoomBoxInv
const MAX_STATIONS = 8;

// Actor properties
var() bool bInitiallyTurnedOn;
var() sound Stations[MAX_STATIONS];

// Internal variables
var int CurrentStation;
var int PendingStation;
var BoomBoxInv LocalBoomBox;

// Replication block
replication
{
	// Stuff the server has to send to the client at the beginning of the game.
	// After this, there is no more communication between the two
	reliable if (Role == ROLE_Authority && bNetInitial)
		bInitiallyTurnedOn, Stations;
}

// Grant players a BoomBoxInv which they can use to control the music on their client.
function ModifyPlayer(Pawn Other)
{
	if (Role == ROLE_Authority && P2Pawn(Other) != None && PlayerController(Other.Controller) != None)
	{
//		log("Spawning BoomBox for" @ Other);
		P2Pawn(Other).CreateInventoryByClass(class'STPExtrasToo.BoomBoxInv');
	}
/*	else if (Role != ROLE_Authority)
		log("Didn't spawn BoomBox for" @ Other @ "because Role was not ROLE_Authority");
	else if (P2Pawn(Owner) == None)
		log("Didn't spawn BoomBox for" @ Other @ "because P2Pawn(Other) == None");
	else if (PlayerController(Other.Controller) != None)
		log("Didn't spawn BoomBox for" @ Other @ "because" @ Other.Controller @ "is not a PlayerController");
	else
		log("Didn't spawn BoomBox, just cuz I didn't feel like doing it.");*/
}

event PostBeginPlay()
{
	if (Level.Game.BaseMutator == None)
		Level.Game.BaseMutator = Self;
	else
		Level.Game.BaseMutator.AddMutator(Self);

	Super.PostBeginPlay();
}

// If bInitiallyTurnedOn, set the radio station to 0 (first station)
simulated event PostNetBeginPlay()
{
	//log("=== PostNetBeginPlay ===");
	//log("Super.PostNetBeginPlay();");
	Super.PostNetBeginPlay();
	if (bInitiallyTurnedOn)
		SetStation(0);
	else
		TurnOff();
	PendingStation = CurrentStation;
	//log("Current Station is" @ CurrentStation);
}

// Set the radio to this station. If there is no sound for the station, turn off the radio.
simulated function SetStation(int Station)
{
	//log("=== SetStation(" $ Station $ ") ===");
	if (Station == -1)
	{
		TurnOff();
		return;
	}
	else
	AmbientSound = Stations[Station];
	if (AmbientSound == None)
	{
		TurnOff();
		return;
	}
	else
		CurrentStation = Station;
	//log("Current Station is now" @ Station $ ", AmbientSound is" @ AmbientSound);
}

// Turn off the radio and set the CurrentStation to -1 (indicating that the radio is off)
simulated function TurnOff()
{
	//log("=== TurnOff ===");
	AmbientSound = None;
	CurrentStation = -1;
	//log("Radio off");
}

simulated event Tick(float Delta)
{
	if (Role == ROLE_Authority && Level.Game.IsInState('MatchOver'))
		Destroy();

	if (LocalBoomBox != None && LocalBoomBox.DesiredChannel != PendingStation)
	{
		//log("=== Tick: LocalBoomBox != None && LocalBoomBox.DesiredChannel != PendingStation");
		PendingStation = LocalBoomBox.DesiredChannel;
		SetStation(PendingStation);
	}
	else if (LocalBoomBox == None)
		LocalBoomBox = None;
//	else
//		log("=== Tick: LocalBoomBox is" @ LocalBoomBox @ "DesiredChannel is" @ LocalBoomBox.DesiredChannel @ "PendingStation is" @ PendingStation);

	Super.Tick(Delta);
}

defaultproperties
{
	// Actor properties.
	RemoteRole=ROLE_SimulatedProxy
	Texture=Texture'FPSGame.SoundThingIcon'

	// Mutator properties.
	FriendlyName="Radio Station"
	Description="Map uses a radio station."

	// RadioStation properties
	bInitiallyTurnedOn=True
	SoundRadius=999999
}
